==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/vo/DcDrwgrpInfoVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.business.dc.bean.DcDrawInfoEntity;
import com.ejianc.business.dc.bean.DcDrawdistributeDrwgrpinfoEntity;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 卷册信息
 * 
 * @author generator
 * 
 */
public class DcDrwgrpInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long id; // 主键id
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer billState; // 单据状态
    private String drwgrpCode; // 卷册编号
    private String oldDrwgrpCode; // 旧卷册编号
    private String drwgrpName; // 卷册名称
    private String drwgrpVsn; // 卷册版本
    private String oldDrwgrpVsn; // 旧卷册版本
    private String drwgrpSts; // 卷册状态
    private Integer drwgrpNum; // 卷册套数
    private Integer surplusNum; // 库存量
    private Long sourceUnitid; // 来源单位id
    private String sourceUnitname; // 来源单位名称
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date drawArriveDate; // 到图日期
    private Long mgrp; // 机组--字典pub_mgrp_code
    private Long specialty; // 专业--字典pub_specialty_code
    private Long sys; // 系统--字典pub_system_code
    private String remarks; // 备注
    private String issueSts; // 签发状态
    private String issueUserCode; // 签发人编号
    private String issueUserName; // 签发人姓名
    private Long createDeptId; // 创建部门id
    private Long orgId; // 所属组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称

    private String billStateName; // 单据状态
    private List<DcDrawInfoVO> dcDrawInfoEntityList = new ArrayList<>();
    private List<DcDrawdistributeDrwgrpinfoVO> dcDrawdistributeDrwgrpinfoEntityList = new ArrayList<>();

    public List<DcDrawInfoVO> getDcDrawInfoEntityList() {
        return dcDrawInfoEntityList;
    }

    public void setDcDrawInfoEntityList(List<DcDrawInfoVO> dcDrawInfoEntityList) {
        this.dcDrawInfoEntityList = dcDrawInfoEntityList;
    }

    public List<DcDrawdistributeDrwgrpinfoVO> getDcDrawdistributeDrwgrpinfoEntityList() {
        return dcDrawdistributeDrwgrpinfoEntityList;
    }

    public void setDcDrawdistributeDrwgrpinfoEntityList(List<DcDrawdistributeDrwgrpinfoVO> dcDrawdistributeDrwgrpinfoEntityList) {
        this.dcDrawdistributeDrwgrpinfoEntityList = dcDrawdistributeDrwgrpinfoEntityList;
    }

    public String getOldDrwgrpCode() {
        return oldDrwgrpCode;
    }

    public void setOldDrwgrpCode(String oldDrwgrpCode) {
        this.oldDrwgrpCode = oldDrwgrpCode;
    }

    public String getOldDrwgrpVsn() {
        return oldDrwgrpVsn;
    }

    public void setOldDrwgrpVsn(String oldDrwgrpVsn) {
        this.oldDrwgrpVsn = oldDrwgrpVsn;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }
    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }
    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }
    public String getDrwgrpSts() {
        return drwgrpSts;
    }

    public void setDrwgrpSts(String drwgrpSts) {
        this.drwgrpSts = drwgrpSts;
    }
    public Integer getDrwgrpNum() {
        return drwgrpNum;
    }

    public void setDrwgrpNum(Integer drwgrpNum) {
        this.drwgrpNum = drwgrpNum;
    }
    public Integer getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(Integer surplusNum) {
        this.surplusNum = surplusNum;
    }
    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }
    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }
    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }
    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }
    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }
    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public String getIssueSts() {
        return issueSts;
    }

    public void setIssueSts(String issueSts) {
        this.issueSts = issueSts;
    }
    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }
    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }
    /**
     * 编制人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getCreateDeptId() {
        return createDeptId;
    }
    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    /**
     * 组织ID
     */
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }
    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    
}

==> ejc-ztpcdc-impl-3.0.0-20230531.020113-32-sources.jar: com/ejianc/business/dc/vo/DcDrwgrpInfoVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 卷册信息
 * 
 * @author generator
 * 
 */
public class DcDrwgrpInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long id; // 主键id
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer billState; // 单据状态
    private String drwgrpCode; // 卷册编号
    private String oldDrwgrpCode; // 旧卷册编号
    private String drwgrpName; // 卷册名称
    private String drwgrpVsn; // 卷册版本
    private String oldDrwgrpVsn; // 旧卷册版本
    private String drwgrpSts; // 卷册状态
    private Integer drwgrpNum; // 卷册套数
    private Integer surplusNum; // 库存量
    private Long sourceUnitid; // 来源单位id
    private String sourceUnitname; // 来源单位名称
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date drawArriveDate; // 到图日期
    private Long mgrp; // 机组--字典pub_mgrp_code
    private Long specialty; // 专业--字典pub_specialty_code
    private Long sys; // 系统--字典pub_system_code
    private String remarks; // 备注
    private String issueSts; // 签发状态
    private String issueUserCode; // 签发人编号
    private String issueUserName; // 签发人姓名
    private Long createDeptId; // 创建部门id
    private Long orgId; // 所属组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称

    //字典包装字段
    private String billStateName; // 单据状态包装  枚举类BillStateEnum
    private String drwgrpStsCn; // 卷册状态包装  枚举类DrwgrpStsEnum
    private String issueStsCn; // 签发状态包装  枚举类IssueStsEnum
    private List<DcDrawInfoVO> dcDrawInfoEntityList = new ArrayList<>();
    private List<DcDrawdistributeDrwgrpinfoVO> dcDrawdistributeDrwgrpinfoEntityList = new ArrayList<>();

    public List<DcDrawInfoVO> getDcDrawInfoEntityList() {
        return dcDrawInfoEntityList;
    }

    public void setDcDrawInfoEntityList(List<DcDrawInfoVO> dcDrawInfoEntityList) {
        this.dcDrawInfoEntityList = dcDrawInfoEntityList;
    }

    public List<DcDrawdistributeDrwgrpinfoVO> getDcDrawdistributeDrwgrpinfoEntityList() {
        return dcDrawdistributeDrwgrpinfoEntityList;
    }

    public void setDcDrawdistributeDrwgrpinfoEntityList(List<DcDrawdistributeDrwgrpinfoVO> dcDrawdistributeDrwgrpinfoEntityList) {
        this.dcDrawdistributeDrwgrpinfoEntityList = dcDrawdistributeDrwgrpinfoEntityList;
    }

    public String getOldDrwgrpCode() {
        return oldDrwgrpCode;
    }

    public void setOldDrwgrpCode(String oldDrwgrpCode) {
        this.oldDrwgrpCode = oldDrwgrpCode;
    }

    public String getOldDrwgrpVsn() {
        return oldDrwgrpVsn;
    }

    public void setOldDrwgrpVsn(String oldDrwgrpVsn) {
        this.oldDrwgrpVsn = oldDrwgrpVsn;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }
    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }
    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }
    public String getDrwgrpSts() {
        return drwgrpSts;
    }
    public void setDrwgrpSts(String drwgrpSts) {
        this.drwgrpSts = drwgrpSts;
    }
    public Integer getDrwgrpNum() {
        return drwgrpNum;
    }

    public void setDrwgrpNum(Integer drwgrpNum) {
        this.drwgrpNum = drwgrpNum;
    }
    public Integer getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(Integer surplusNum) {
        this.surplusNum = surplusNum;
    }
    @ReferSerialTransfer(referCode = "Dc-drawSourceMaintenance-Menu-Refer")
    public Long getSourceUnitid() {
        return sourceUnitid;
    }
    @ReferDeserialTransfer
    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }
    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getDrwgrpType() {
        return drwgrpType;
    }
    @ReferDeserialTransfer
    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }
    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMgrp() {
        return mgrp;
    }

    @ReferDeserialTransfer
    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSpecialty() {
        return specialty;
    }

    @ReferDeserialTransfer
    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSys() {
        return sys;
    }

    @ReferDeserialTransfer
    public void setSys(Long sys) {
        this.sys = sys;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public String getIssueSts() {
        return issueSts;
    }
    public void setIssueSts(String issueSts) {
        this.issueSts = issueSts;
    }
    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }
    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }
    /**
     * 编制人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getCreateDeptId() {
        return createDeptId;
    }
    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    /**
     * 组织ID
     */
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }
    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getDrwgrpStsCn() {
        return drwgrpStsCn;
    }

    public void setDrwgrpStsCn(String drwgrpStsCn) {
        this.drwgrpStsCn = drwgrpStsCn;
    }

    public String getIssueStsCn() {
        return issueStsCn;
    }

    public void setIssueStsCn(String issueStsCn) {
        this.issueStsCn = issueStsCn;
    }
}
